@@ -48,28 +48,18 @@
 
 #include "miniserver.h"
 
-#include "httputils.h"
-#include "ssdplib.h"
-#include "statcodes.h"
 #include "ThreadPool.h"
-#include "upnpapi.h"
 #include "genut.h"
+#include "ssdplib.h"
+#include "upnpapi.h"
 #include "uri.h"
-#include "netif.h"
-#include "upnp.h"
 
-#include <cassert>
+#include <algorithm>
 #include <cerrno>
 #include <chrono>
-#include <cstdio>
-#include <cstdlib>
-#include <cstring>
-#include <iostream>
-#include <sys/types.h>
-#include <stdarg.h>
-#include <thread>
-#include <algorithm>
 #include <condition_variable>
+#include <cstdio>
+#include <cstring>
 
 #include <microhttpd.h>
 
@@ -104,7 +94,7 @@ static MiniServerCallback gGenaCallback = nullptr;
 
 void SetHTTPGetCallback(MiniServerCallback callback)
 {
-    std::lock_guard<std::mutex> lck(gMServStateMutex);
+    std::scoped_lock lck(gMServStateMutex);
     gGetCallback = callback;
 }
 
@@ -212,7 +202,7 @@ static MHD_Result filter_connections(
 // exploit implemented in a local browser. Of course this supposes that the
 // browser will actually set a meaningful HOST, which they appear to do.
 enum VHH_Status{VHH_YES, VHH_NO, VHH_REDIRECT};
-static VHH_Status validate_host_header(MHDTransaction *mhdt, NetIF::IPAddr& claddr)
+static VHH_Status validate_host_header(MHDTransaction* mhdt, const NetIF::IPAddr& claddr)
 {
     // Find HOST header
     auto hostit = mhdt->headers.find("host");
@@ -285,7 +275,7 @@ static VHH_Status validate_host_header(MHDTransaction *mhdt, NetIF::IPAddr& clad
 }
 
 static std::string rebuild_url_from_mhdt(
-    MHDTransaction *mhdt, const std::string& path, NetIF::IPAddr& claddr)
+    MHDTransaction* mhdt, const std::string& path, const NetIF::IPAddr& claddr)
 {
     std::string aurl("http://");
     auto hostport = UpnpGetUrlHostPortForClient(mhdt->client_address);
@@ -403,7 +393,7 @@ static MHD_Result answer_to_connection(
     case HTTPMETHOD_POST:
     case HTTPMETHOD_HEAD:
     {
-        std::lock_guard<std::mutex> lck(gMServStateMutex);
+        std::scoped_lock lck(gMServStateMutex);
         callback = gGetCallback;
         break;
     }
@@ -503,7 +493,7 @@ void MiniServerJobWorker::work()
     ++maxMiniSock;
 
     {
-        std::unique_lock<std::mutex> lck(gMServStateMutex);
+        std::scoped_lock lck(gMServStateMutex);
         gMServState = MSERV_RUNNING;
         gMServStateCV.notify_all();
     }
@@ -545,11 +535,10 @@ void MiniServerJobWorker::work()
             ssdp_read(miniSocket->ssdpSock6, &rdSet);
             ssdp_read(miniSocket->ssdpSock6UlaGua, &rdSet);
         }
-        stopSock = receive_from_stopSock(
-            miniSocket->miniServerStopSock, &rdSet);
+        stopSock = receive_from_stopSock(miniSocket->miniServerStopSock, &rdSet);
     }
 
-    std::unique_lock<std::mutex> lck(gMServStateMutex);
+    std::scoped_lock lck(gMServStateMutex);
     delete miniSocket;
     miniSocket = nullptr;
     gMServState = MSERV_IDLE;
@@ -719,7 +708,7 @@ int StartMiniServer(uint16_t *listen_port4, uint16_t *listen_port6)
     unsigned int mhdflags = 0;
 
     {
-        std::unique_lock<std::mutex> lck(gMServStateMutex);
+        std::scoped_lock lck(gMServStateMutex);
         if (gMServState != MSERV_IDLE) {
             /* miniserver running. */
             UpnpPrintf(UPNP_CRITICAL, MSERV, __FILE__, __LINE__, "miniserver: ALREADY RUNNING !\n");
@@ -741,8 +730,18 @@ int StartMiniServer(uint16_t *listen_port4, uint16_t *listen_port6)
         goto out;
     }
 
+    /* Check what port we should listen on */
+    port = available_port(static_cast<int>(*listen_port4));
+    if (port < 0) {
+        UpnpPrintf(UPNP_CRITICAL, MSERV, __FILE__, __LINE__,
+                   "miniserver: available_port() failed !\n");
+        return port;
+    }
+    *listen_port4 = port;
+    *listen_port6 = port;
+
     /* SSDP socket for discovery/advertising. */
-    ret_code = get_ssdp_sockets(miniSocket);
+    ret_code = get_ssdp_sockets(miniSocket, port);
     if (ret_code != UPNP_E_SUCCESS) {
         UpnpPrintf(UPNP_CRITICAL, MSERV, __FILE__, __LINE__,
                    "miniserver: get_ssdp_sockets() failed\n");
@@ -769,15 +768,6 @@ int StartMiniServer(uint16_t *listen_port4, uint16_t *listen_port6)
     }
     
 #ifdef INTERNAL_WEB_SERVER
-    port = available_port(static_cast<int>(*listen_port4));
-    if (port < 0) {
-        UpnpPrintf(UPNP_CRITICAL, MSERV, __FILE__, __LINE__,
-                   "miniserver: available_port() failed !\n");
-        return port;
-    }
-    *listen_port4 = port;
-    *listen_port6 = port;
-
     mhdflags = MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_DEBUG;
 
 #ifdef UPNP_ENABLE_IPV6
@@ -825,6 +815,10 @@ int StopMiniServer()
         return 0;
     }
 
+#ifdef INTERNAL_WEB_SERVER
+    MHD_stop_daemon(mhd);
+#endif
+
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == INVALID_SOCKET) {
         posix_strerror_r(errno, errorBuffer, ERROR_BUFFER_LEN);
