@@ -36,19 +36,16 @@
 #if EXCLUDE_GENA == 0
 #ifdef INCLUDE_DEVICE_APIS
 
-#include <sstream>
 #include <iostream>
+#include <sstream>
 
 #include <curl/curl.h>
 
-#include <cassert>
-
 #include "gena.h"
-#include "httputils.h"
-#include "statcodes.h"
-#include "upnpapi.h"
 #include "gena_sids.h"
 #include "genut.h"
+#include "statcodes.h"
+#include "upnpapi.h"
 #include "uri.h"
 
 static constexpr auto XML_PROPERTYSET_HEADER =
@@ -713,7 +710,7 @@ static int create_url_list(
 
         UpnpPrintf(UPNP_DEBUG, GENA, __FILE__, __LINE__,
                    "create_url_list: cb url ok:  %s\n", qsurl.c_str());
-        out->push_back(qsurl);
+        out->push_back(std::move(qsurl));
     }
     return UPNP_E_SUCCESS;
 }
