@@ -37,23 +37,21 @@
 #endif
 
 #include "netif.h"
+#include "smallut.h"
 
-#include <cstring>
-#include <ostream>
-#include <vector>
-#include <iostream>
 #include <algorithm>
+#include <cstring>
 #include <numeric>
+#include <ostream>
 #include <sstream>
-#include <cstdint>
+#include <vector>
 
 #ifndef _WIN32
 
-#include <sys/types.h>
 #include <arpa/inet.h>
-#include <netinet/in.h>
-#include <net/if.h>
 #include <ifaddrs.h>
+#include <net/if.h>
+#include <netinet/in.h>
 #ifdef __linux__
 #include <netpacket/packet.h>
 #elif !defined(__CYGWIN__)
@@ -780,9 +778,13 @@ Interfaces *Interfaces::theInterfaces()
     return theInterfacesP;
 }
 
+void Interfaces::cleanup()
+{
+    deleteZ(theInterfacesP);
+}
+
 std::ostream& Interfaces::print(std::ostream& out) {
-    const auto& ifs = theInterfaces()->m->interfaces;
-    for (const auto& entry : ifs) {
+    for (const auto& entry : theInterfaces()->m->interfaces) {
         entry.print(out);
         out << "\n";
     }
@@ -792,10 +794,12 @@ std::ostream& Interfaces::print(std::ostream& out) {
 std::vector<Interface> Interfaces::select(const Filter& filt) const
 {
     uint32_t yesflags = std::accumulate(filt.needs.begin(), filt.needs.end(), 0,
-        [](uint32_t yes, const NetIF::Interface::Flags &f){ return yes | static_cast<unsigned int>(f); });
+        [](uint32_t yes, const NetIF::Interface::Flags &f){
+            return yes | static_cast<unsigned int>(f); });
 
     uint32_t noflags = std::accumulate(filt.rejects.begin(), filt.rejects.end(), 0,
-        [](uint32_t no, const NetIF::Interface::Flags &f){ return no | static_cast<unsigned int>(f); });
+        [](uint32_t no, const NetIF::Interface::Flags &f){
+            return no | static_cast<unsigned int>(f); });
 
     LOGDEB("Interfaces::select: yesflags " << std::hex << yesflags <<
            " noflags " << noflags << std::dec << "\n");
